from airspeed import Template
from moban.externals import file_system


class EngineVelocity(object):
    ACTION_IN_PRESENT_CONTINUOUS_TENSE = "Velocity-templating"
    ACTION_IN_PAST_TENSE = "Velocity-templated"

    def __init__(self, template_fs, options=None):
        """
        template_fs is a multfs instance and gives you the power to load
        a template from equiped template directories.
        :param fs.multifs.MultiFS template_fs: a MultiFS instance or an FS
        instance
        :param options: a dictionary of potential parameters.
                        not used yet.
        """
        self.template_fs = template_fs

    def get_template(self, template_file):
        template_file = file_system.to_unicode(template_file)
        template = self.template_fs.readtext(template_file)
        template = Template(template)
        return template

    def get_template_from_string(self, string):
        return Template(string)

    def apply_template(self, template, data, output):
        rendered_content = template.merge(data)
        return rendered_content



import os

from moban.core import ENGINES, plugins
from nose.tools import eq_

plugins.make_sure_all_pkg_are_loaded()


def test_velocity_engine_type():
    engine = ENGINES.get_engine("velocity", [], "")
    assert engine.engine.__class__.__name__ == "EngineVelocity"


def test_velocity_file_test():
    output = "test.txt"
    path = os.path.join("tests", "fixtures", "velocity_tests")
    engine = ENGINES.get_engine("velocity", [path], path)
    engine.render_to_file("file_tests.velocity", "file_tests.json", output)
    with open(output, "r") as output_file:
        expected_path = os.path.join(
            "tests", "fixtures", "velocity_tests", "expected_output.txt"
        )
        with open(expected_path) as expected_file:
            expected = expected_file.read()
            content = output_file.read()
            eq_(content, expected)
    os.unlink(output)


def test_velocity_string_template():
    string_template = "Hello $hello"
    output = "test.txt"
    path = os.path.join("tests", "fixtures", "velocity_tests")
    engine = ENGINES.get_engine("velocity", [path], path)
    engine.render_string_to_file(string_template, "file_tests.json", output)
    with open(output, "r") as output_file:
        expected = "Hello World!"
        content = output_file.read()
        eq_(content, expected)
    os.unlink(output)
